@@ -1,10 +1,10 @@
 # Functions for the book Applied Hierarchical Modeling in Ecology (AHM)
 # Marc Kery & Andy Royle, Academic Press, 2016.
 
-# simHDSopen - section 9.5.4.1 p499
+# simHDSopen - AHM1 section 9.5.4.1 p499
 
 # Function to generate open hierarchical distance sampling data
-#   (introduced in Section 9.5.4.1)
+#   (introduced in AHM1 Section 9.5.4.1)
 
 simHDSopen <-
 function(type=c("line", "point"), nsites = 100, mean.lam = 2,
@@ -25,10 +25,15 @@ beta.lam = 0, mean.sig = 1, beta.sig = 0, B = 3, discard0=TRUE, nreps=2, phi=0.7
 #
 #   more things here
 #
-#
 #  Note: for "point" the realized density is
 #[(area of circle) /(area of  square)]*lambda
 
+# Checks and fixes for input data -----------------------------
+nsites <- round(nsites[1])
+stopifNegative(mean.lam, allowZero=FALSE)
+stopifNegative(B, allowZero=FALSE)
+# --------------------------------------------
+
 type <- match.arg(type)
 
 parmvec <- c(mean.lam, beta.lam, mean.sig, beta.sig, phi, beta.trend)
